Installation
============

Feijoa supports Python 3.6 or newer.

We recommend to install feijoa via pip:

.. code-block:: bash

    $ pip install feijoa

If you want use all features, use:

.. code-block:: bash
   
    $ pip install feijoa[all]

If you on zsh, please use:

.. code-block:: bash

    $ pip install 'feijoa[all]'

For development version, install:

.. code-block:: bash

    $ pip install 'feijoa[dev]'
